from parsagon.main import update, detail, delete, get_product, get_review_article, get_article_list
from parsagon.create import create_program as create
from parsagon.runs import run, batch_runs
from parsagon.api import get_json_about_data
